==> chromium-63.0.3239.83.tar.xz: chromium-63.0.3239.83/chrome/android/java/src/org/chromium/chrome/browser/download/DownloadSheetContent.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.download;

import android.view.View;

import org.chromium.base.ActivityState;
import org.chromium.base.ApplicationStatus;
import org.chromium.base.ApplicationStatus.ActivityStateListener;
import org.chromium.base.CollectionUtil;
import org.chromium.base.ThreadUtils;
import org.chromium.chrome.browser.ChromeActivity;
import org.chromium.chrome.browser.download.ui.DownloadHistoryItemWrapper;
import org.chromium.chrome.browser.download.ui.DownloadManagerUi;
import org.chromium.chrome.browser.snackbar.SnackbarManager;
import org.chromium.chrome.browser.toolbar.BottomToolbarPhone;
import org.chromium.chrome.browser.widget.bottomsheet.BottomSheet;
import org.chromium.chrome.browser.widget.bottomsheet.BottomSheet.BottomSheetContent;
import org.chromium.chrome.browser.widget.bottomsheet.BottomSheetContentController;
import org.chromium.chrome.browser.widget.selection.SelectableListToolbar;

import java.util.List;

/**
 * A {@link BottomSheetContent} holding a {@link DownloadManagerUi} for display in the BottomSheet.
 */
public class DownloadSheetContent implements BottomSheetContent {
    private final View mContentView;
    private final SelectableListToolbar<DownloadHistoryItemWrapper> mToolbarView;
    private final ActivityStateListener mActivityStateListener;
    private DownloadManagerUi mDownloadManager;

    /**
     * @param activity The activity displaying the download manager UI.
     * @param isIncognito Whether the activity is currently displaying an incognito tab.
     * @param snackbarManager The {@link SnackbarManager} used to display snackbars.
     */
    public DownloadSheetContent(final ChromeActivity activity, final boolean isIncognito,
            SnackbarManager snackbarManager) {
        ThreadUtils.assertOnUiThread();

        mDownloadManager = new DownloadManagerUi(
                activity, isIncognito, activity.getComponentName(), false, snackbarManager);
        mContentView = mDownloadManager.getView();
        mToolbarView = mDownloadManager.detachToolbarView();
        mToolbarView.addObserver(new SelectableListToolbar.SelectableListToolbarObserver() {
            @Override
            public void onThemeColorChanged(boolean isLightTheme) {
                activity.getBottomSheet().updateHandleTint();
            }

            @Override
            public void onStartSearch() {
                activity.getBottomSheet().setSheetState(BottomSheet.SHEET_STATE_FULL, true);
            }
        });
        ((BottomToolbarPhone) activity.getToolbarManager().getToolbar())
                .setOtherToolbarStyle(mToolbarView);

        // #destroy() unregisters the ActivityStateListener to avoid checking for externally removed
        // downloads after the downloads UI is closed. This requires each download UI to have its
        // own ActivityStateListener. If multiple tabs are showing the downloads page, multiple
        // requests to check for externally removed downloads will be issued when the activity is
        // resumed.
        mActivityStateListener = (activity1, newState) -> {
            if (newState == ActivityState.RESUMED) {
                DownloadUtils.checkForExternallyRemovedDownloads(
                        mDownloadManager.getBackendProvider(), isIncognito);
            }
        };
        ApplicationStatus.registerStateListenerForActivity(mActivityStateListener, activity);

        mToolbarView.setActionBarDelegate(activity.getBottomSheet().getActionBarDelegate());
    }

    @Override
    public View getContentView() {
        return mContentView;
    }

    @Override
    public List<View> getViewsForPadding() {
        return CollectionUtil.newArrayList(
                mDownloadManager.getRecyclerView(), mDownloadManager.getEmptyView());
    }

    @Override
    public View getToolbarView() {
        return mToolbarView;
    }

    @Override
    public boolean isUsingLightToolbarTheme() {
        return mToolbarView.isLightTheme();
    }

    @Override
    public boolean isIncognitoThemedContent() {
        return false;
    }

    @Override
    public int getVerticalScrollOffset() {
        return mDownloadManager.getVerticalScrollOffset();
    }

    @Override
    public void destroy() {
        mDownloadManager.onDestroyed();
        mDownloadManager = null;
        ApplicationStatus.unregisterActivityStateListener(mActivityStateListener);
    }

    @Override
    public int getType() {
        return BottomSheetContentController.TYPE_DOWNLOADS;
    }

    @Override
    public boolean applyDefaultTopPadding() {
        return false;
    }

    @Override
    public void scrollToTop() {
        mDownloadManager.scrollToTop();
    }
}

==> chromium-64.0.3282.186.tar.xz: chromium-64.0.3282.186/chrome/android/java/src/org/chromium/chrome/browser/download/DownloadSheetContent.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.download;

import org.chromium.base.ActivityState;
import org.chromium.base.ApplicationStatus;
import org.chromium.base.ApplicationStatus.ActivityStateListener;
import org.chromium.base.ThreadUtils;
import org.chromium.chrome.browser.ChromeActivity;
import org.chromium.chrome.browser.download.ui.DownloadHistoryItemWrapper;
import org.chromium.chrome.browser.download.ui.DownloadManagerUi;
import org.chromium.chrome.browser.snackbar.SnackbarManager;
import org.chromium.chrome.browser.widget.bottomsheet.BottomSheet.BottomSheetContent;
import org.chromium.chrome.browser.widget.bottomsheet.BottomSheetContentController;
import org.chromium.chrome.browser.widget.selection.SelectableBottomSheetContent;

/**
 * A {@link BottomSheetContent} holding a {@link DownloadManagerUi} for display in the BottomSheet.
 */
public class DownloadSheetContent extends SelectableBottomSheetContent<DownloadHistoryItemWrapper> {
    private final ActivityStateListener mActivityStateListener;

    /**
     * @param activity The activity displaying the download manager UI.
     * @param isIncognito Whether the activity is currently displaying an incognito tab.
     * @param snackbarManager The {@link SnackbarManager} used to display snackbars.
     */
    public DownloadSheetContent(final ChromeActivity activity, final boolean isIncognito,
            SnackbarManager snackbarManager) {
        super();

        ThreadUtils.assertOnUiThread();

        DownloadManagerUi downloadManager = new DownloadManagerUi(
                activity, isIncognito, activity.getComponentName(), false, snackbarManager);
        initialize(activity, downloadManager);

        // #destroy() unregisters the ActivityStateListener to avoid checking for externally removed
        // downloads after the downloads UI is closed. This requires each download UI to have its
        // own ActivityStateListener. If multiple tabs are showing the downloads page, multiple
        // requests to check for externally removed downloads will be issued when the activity is
        // resumed.
        mActivityStateListener = (activity1, newState) -> {
            if (newState == ActivityState.RESUMED) {
                DownloadUtils.checkForExternallyRemovedDownloads(
                        downloadManager.getBackendProvider(), isIncognito);
            }
        };
        ApplicationStatus.registerStateListenerForActivity(mActivityStateListener, activity);
    }

    @Override
    public void destroy() {
        super.destroy();
        ApplicationStatus.unregisterActivityStateListener(mActivityStateListener);
    }

    @Override
    public int getType() {
        return BottomSheetContentController.TYPE_DOWNLOADS;
    }
}
